__version__ = "0.1.10"

import warnings

try:
    from .ipython_traceback import *
except ImportError:
    warnings.warn("IPython could not be imported, are you in Google Colab?")

def deactivate():
    IPython.get_ipython().set_custom_exc((Exception,),
                                     None)


from rich.traceback import  Traceback
from rich.console import Console

console = Console()

def print_exception(exc_type, exc_value, exc_traceback):
    tb_offset = 0
    ltb = tb
    for _ in range(tb_offset):
        if ltb is None:
            break
        ltb = ltb.tb_next
    locals_hide_sunder = None
    locals_hide_sunder = (
        True
        if (console.is_jupyter and locals_hide_sunder is None)
        else locals_hide_sunder
    )
    traceback_exception = Traceback.from_exception(
                exc_type,
                exc_value,
                exc_traceback,
                width = 100,
    extra_lines = 3,
    theme= None,
    word_wrap = False,
    show_locals =  False,
    locals_max_length =  10,
    locals_max_string =  80,
    locals_hide_dunder =  True,
    locals_hide_sunder =  locals_hide_sunder,
    indent_guides =  True,
    suppress =   (),
    max_frames =  100,
            )
    console.print(
            traceback_exception
        )


import requests
import os

def predict_prompt(prompt):
  apiKey = os.environ["OPENAI_API_KEY"]
  model = 'text-davinci-003'
  temperature = 0.
  maxTokens = 150

  url = 'https://api.openai.com/v1/completions'
  headers = {
      'Content-Type': 'application/json',
      'Authorization': 'Bearer ' + apiKey
  }
  payload = {
      'model': model,
      'prompt': prompt,
      'temperature': temperature,
      'max_tokens': maxTokens
  }

  response = requests.post(url, headers=headers, data=json.dumps(payload))

  response_json = json.loads(response.text)
  return response_json['choices'][0]['text']


import IPython, inspect
import textwrap
from IPython.core import ultratb
import traceback
from .prompt import predict_prompt
from .print_exception import print_exception

def exception_hook(exc_type, exc_value, exc_traceback):
    last_tb = exc_traceback
    while last_tb.tb_next:
        last_tb = last_tb.tb_next
    source = inspect.getsource(last_tb.tb_frame)
    print_exception(exc_type, exc_value, exc_traceback)
    error = "Hello stack overflow, I need help I ran into the following error in my notebook:\n"
    exception = "\n".join(traceback.format_exception_only(exc_type, exc_value))
    error += "Exception type and exception value:\n" + exception + "\n"
    traceback_str ="\n".join(traceback.format_tb(exc_traceback, 2))
    error += "Traceback (2):\n" + traceback_str + "\n"
    error += "Source of cell:\n" + source + "\nThe solution to the exception is:"
    formatted_string = textwrap.wrap(predict_prompt(error), width=60)
    print("\n".join(formatted_string))
    
def custom_exc(shell, etype, evalue, tb, tb_offset=None):
  lshell = shell
  ltb_offset = tb_offset
  return exception_hook(etype, evalue, tb)
  


IPython.get_ipython().set_custom_exc((Exception,),
                                     custom_exc)